@@ -2,7 +2,7 @@ package Web::Hippie;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 use parent 'Plack::Middleware';
 
 use Plack::Util::Accessor qw( on_error on_message trusted_origin );
@@ -96,12 +96,6 @@ sub handler_ws {
     my $req = Plack::Request->new($env);
     my $res = $req->new_response(200);
 
-    my $trusted_origin = $self->trusted_origin || '.*';
-    if ($env->{HTTP_ORIGIN} !~ m/^$trusted_origin/) {
-        $env->{'psgi.errors'}->print("Client origin $env->{HTTP_ORIGIN} not allowed.\n");
-        return [403, ['Content-Type' => 'text/plain'], ['origin not allowed']];
-    }
-
     my $hs = Protocol::WebSocket::Handshake::Server->new_from_psgi($env);
     my $client_id = $req->param('client_id') || rand(1);
 
@@ -112,6 +106,14 @@ sub handler_ws {
              [ "Failed to initialize websocket" ] ]
         unless $hs->parse($fh);
 
+    if (my $origin = $hs->req->origin) {
+        my $trusted_origin = $self->trusted_origin || '.*';
+        if ($origin !~ m/^$trusted_origin/) {
+            $env->{'psgi.errors'}->print("Client origin $origin not allowed.\n");
+            return [403, ['Content-Type' => 'text/plain'], ['origin not allowed']];
+        }
+    }
+
     return [ 501, [ "Content-Type", "text/plain" ],
              [ "websocket handshake incomplete" ] ]
         unless $hs->is_done;
